@@ -493,6 +493,8 @@ class XMPPClient:
         self._last_known_party_id = None
         self._task = None
 
+        self.send_presence_on_add = True
+
     def jid(self, user_id: str) -> aioxmpp.JID:
         return aioxmpp.JID.fromstr('{}@{}'.format(
             user_id,
@@ -610,6 +612,16 @@ class XMPPClient:
             except KeyError:
                 pass
 
+            # Send presence to the newly added friend as that is now
+            # required to do by the server (or at least thats what
+            # i suspect)
+            if self.send_presence_on_add:
+                self.client.loop.create_task(self.send_presence(
+                    to=f.jid,
+                    status=self.client.party.last_raw_status,
+                    show=self.client.away.value
+                ))
+
             self.client.dispatch_event('friend_add', f)
 
         elif _status == 'PENDING':
@@ -737,7 +749,7 @@ class XMPPClient:
                 net_cl = self.client.net_cl
         else:
             s = invite['meta']['urn:epic:cfg:build-id_s']
-            net_cl = s[4:] if s.startswith('1:1:') else s
+            net_cl = s[4:] if s.startswith('1:') else s
 
         if net_cl != self.client.net_cl and self.client.net_cl != '':
             log.debug(
